@@ -19,6 +19,7 @@ import shutil
 import sys
 import textwrap
 import time
+import uuid
 
 import cpuinfo
 
@@ -28,6 +29,7 @@ import seamm_util
 logging.basicConfig(level="WARNING")
 logger = logging.getLogger(__name__)
 variables = seamm.Variables()
+header_line = "!MolSSI job_data 1.0\n"
 
 
 class cd:
@@ -85,84 +87,6 @@ def run(job_id=None, wdir=None, setup_logging=True, in_jobserver=False):
     )
     parser.usage = "%(prog)s [options] plug-in [options] plug-in [options] ..."
 
-    # add options for the job
-    parser.add_argument_group("SEAMM", "job options", "Options for jobs")
-
-    parser.add_argument(
-        "SEAMM",
-        "--standalone",
-        group="job options",
-        action="store_true",
-        help="Run this workflow as-is without using the job, etc.",
-    )
-    parser.add_argument(
-        "SEAMM",
-        "--project",
-        group="job options",
-        dest="projects",
-        action="append",
-        help="The project(s) for this job.",
-    )
-    parser.add_argument(
-        "SEAMM",
-        "--title",
-        group="job options",
-        dest="title",
-        default="",
-        action="store",
-        help="The title for this run.",
-    )
-    parser.add_argument(
-        "SEAMM",
-        "--force",
-        group="job options",
-        dest="force",
-        action="store_true",
-        help="Overwrite the job output if it exists.",
-    )
-
-    # Hardware options
-    parser.add_argument_group(
-        "SEAMM",
-        "hardware options",
-        (
-            "Options about memory limits, parallelism and other details "
-            "connected with hardware."
-        ),
-    )
-
-    parser.add_argument(
-        "SEAMM",
-        "--parallelism",
-        group="hardware options",
-        default="any",
-        choices=["none", "mpi", "openmp", "any"],
-        help="Whether to limit parallel usage to certain types.",
-    )
-
-    parser.add_argument(
-        "SEAMM",
-        "--ncores",
-        group="hardware options",
-        default="available",
-        help=(
-            "The maximum number of cores/threads to use in any step. "
-            "Default: all available cores."
-        ),
-    )
-
-    parser.add_argument(
-        "SEAMM",
-        "--memory",
-        group="hardware options",
-        default="available",
-        help=(
-            "The maximum amount of memory to use in any step, which can be "
-            "'all' or 'available', or a number, which may use k, Ki, "
-            "M, Mi, etc. suffixes. Default: available."
-        ),
-    )
-
     # Now we need to get the flowchart so that we can set up all the
     # parsers for the steps in order to provide appropriate help.
     if not os.path.exists(filename):
@@ -276,21 +200,19 @@ def run(job_id=None, wdir=None, setup_logging=True, in_jobserver=False):
 
     # Change to the working directory and run the flowchart
     with cd(wdir):
-        if os.path.exists("job_data.json"):
-            with open("job_data.json", "r") as fd:
-                data = json.load(fd)
-        else:
-            data = {}
-
         # Set up the initial metadata for the job.
-        data.update(cpuinfo.get_cpu_info())
-        if "command line" not in data:
-            data["command line"] = sys.argv
-        if "title" not in data:
-            data["title"] = options["title"]
-        data["working directory"] = wdir
-        data["start time"] = time.strftime("%Y-%m-%d %H:%M:%S %Z")
-        data["state"] = "started"
+        data = {
+            "command line": sys.argv,
+            "data_version": "1.0",
+            "flowchart_digest": flowchart.digest(),
+            "flowchart_digest_strict": flowchart.digest(strict=True),
+            "start time": time.strftime("%Y-%m-%d %H:%M:%S %Z"),
+            "state": "started",
+            "title": options["title"],
+            "uuid": uuid.uuid4().hex,
+            "working directory": wdir,
+            "~cpuinfo": cpuinfo.get_cpu_info(),
+        }
         if not standalone:
             if "projects" not in data:
                 data["projects"] = projects
@@ -299,7 +221,9 @@ def run(job_id=None, wdir=None, setup_logging=True, in_jobserver=False):
 
         # Output the initial metadate for the job.
         with open("job_data.json", "w") as fd:
+            fd.write(header_line)
             json.dump(data, fd, indent=3, sort_keys=True)
+            fd.write("\n")
 
         t0 = time.time()
         pt0 = time.process_time()
@@ -325,7 +249,9 @@ def run(job_id=None, wdir=None, setup_logging=True, in_jobserver=False):
         data["process time"] = pt
 
         with open("job_data.json", "w") as fd:
+            fd.write(header_line)
             json.dump(data, fd, indent=3, sort_keys=True)
+            fd.write("\n")
 
         printer.job(
             "\nProcess time: {} ({:.3f} s)".format(datetime.timedelta(seconds=pt), pt)
